@@ -1,6 +1,14 @@
+//! # Diesel Support
+//!
+//! Diesel support is included in this module. Moreover, to activate it, use
+//! the embeded migrations (or write your own.) The schema is included from lib.
+
 use super::User;
 use crate::schema::*;
 use crate::Permissions;
+use diesel_migrations::embed_migrations;
+
+embed_migrations!("migrations/");
 
 /// This is the diesel version of a user, meaning it is not designed to be
 /// worked with but rathre used as an intermediary between the databases
